# Simple CRUD Example

This template shows off a simple CRUD App, which allows you to create,
read, update, and delete menu items.

## Components

The example is composed of three main components:

1. CrudPage: Displays messages to the user.
2. ItemList: Displays the list of menu items and allows the user to add new items, delete existing items, or select an item for editing.
3. ItemEditor: Allows the user to edit the details of a selected menu item.

The app has a single chat page, where you can type in a message and get a
response. If there aren't any messages yet, the bot displays a placeholder with
helfpul suggestions to the user. Once the first message is entered, it switches
to a conversation view.
